// THIS PROGRAM RUNS PROCEDURES FOR MASTER DATABASE 2018-2023 FOR MITIGATION POLICIES ///
// DATE CREATED: 2025-03-27//
// AUTHOR: Euijin Jung (ejung1@worldbank.org)

*************************************************************************
******** USING 2022 DATA*****

clear all
set more off

//global main "C:\Users\wb601501\Documents\Data"

global wb_class "$main\ISO_Region_Income.dta"
global gdp "$main\gdp 2018-2023.dta"
 
cd "$main\"

*******************************
clear

import excel "$main\HS codes for policy product.xlsx", sheet("HS17_dup") firstrow
keep if Product1=="CM"
duplicates drop
keep Product1 Product2 HS17
split Product2, parse(" ")
keep Product1 Product2 HS17 Product21 Product22
replace Product21 = subinstr( Product21 , ",", "", .)
replace Product21 = subinstr( Product21 , ",", "", .)
replace Product21 = subinstr( Product21 , ";", "", .)
so Product21
rename Product21 a1
order a1 Product22 Product2
egen gr=group(a1)
order gr
tostring gr, replace
replace gr="00" if a1=="Aluminum"|a1=="Cobalt"|a1=="Antimony"|a1=="Beryllium"|a1=="Bismuth"|a1=="Arsenic"|a1=="Boron"|a1=="Fluorspar"|a1=="Germanium"|a1=="Lithium"|a1=="Magnesium"|a1=="Manganese"|a1=="Natural"|a1=="Nickel"|a1=="Platinum"|a1=="Rare-earth"|a1=="Tantalum"|a1=="Titanium"|a1=="Tungsten"|a1=="Vanadium"|a1=="Fluorspar"|a1=="Zinc"|a1=="Iridium"|a1=="Palladium"|a1=="Rhodium"|a1=="Copper"| a1=="Zirconium"| a1=="Lead" |a1=="Tin" 
tostring HS17,replace
order HS17
replace a1="Ferrous metals" if HS17=="720249"|HS=="720241"|HS=="720219"|HS=="720211"|HS=="720260"|HS=="720293"|HS=="720230"|HS=="720250"|HS=="720291"|HS=="720280"|HS=="720292"|HS=="720299"
replace a1="Natural graphite" if HS=="250410"|HS=="250490"
replace a1="Platinum group metals" if a1=="Iridium"|a1=="Palladium"|a1=="Rhodium"|a1=="Platinum"
so gr a1
replace a1="Other" if gr!="00"
replace a1="Other" if a1=="Natural"
replace a1="Rare-earth metals" if a1=="Rare-earth"
replace a1="Ferrous metals" if HS17=="720249"|HS=="720241"|HS=="720219"|HS=="720211"|HS=="720260"|HS=="720293"|HS=="720230"|HS=="720250"|HS=="720291"|HS=="720280"|HS=="720292"|HS=="720299"
so a1
drop gr Product22 Product2
rename a1 pro2
rename Product1 pro1
save "$main\cm.dta", replace

clear
import excel "$main\HS codes for policy product.xlsx", sheet("HS17_dup") firstrow
rename Productd des
keep Product1 Product2 HS17 des
rename Product1 pro1
tostring HS, replace
merge 1:1 pro1 HS using "$main\cm.dta"
so _m
replace pro2=Product2 if missing(pro2)
drop Product2 _merge
order HS
so pro1 pro2 HS
replace HS = "0" + HS if length(HS) == 5
replace HS = "0" + HS if length(HS) == 3
save "$main\mp_hscode.dta", replace
clear
*************************************

import delimited "$main\2018.csv"
tempfile 2018
save `2018',replace
clear
import delimited "$main\2019.csv"
tempfile 2019
save `2019',replace
clear
import delimited "$main\2020.csv"
tempfile 2020
save `2020',replace
clear
import delimited "$main\2021.csv"
tempfile 2021
save `2021',replace
clear
import delimited "$main\2022.csv"
tempfile 2022
save `2022',replace
clear
import delimited "$main\2023.csv"
tempfile 2023
save `2023',replace
clear
import delimited "$main\2018e.csv"
tempfile 2018e
save `2018e',replace
clear
import delimited "$main\2019e.csv"
tempfile 2019e
save `2019e',replace
clear
import delimited "$main\2020e.csv"
tempfile 2020e
save `2020e',replace
clear
import delimited "$main\2021e.csv"
tempfile 2021e
save `2021e',replace
clear
import delimited "$main\2022e.csv"
tempfile 2022e
save `2022e',replace
clear
import delimited "$main\2023e.csv"
tempfile 2023e
save `2023e',replace

clear
use `2018'
append using `2019'
append using `2020'
append using `2021'
append using `2022'
append using `2023'
append using `2018e'
append using `2019e'
append using `2020e'
append using `2021e'
append using `2022e'
append using `2023e'

rename productcode HS17
rename reporteriso3 ReporterISO3
rename partneriso3 PartnerISO3
replace PartnerISO3="COD" if PartnerISO3=="ZAR"
replace PartnerISO3="ROU" if PartnerISO3=="ROM"
replace PartnerISO3="TWN" if PartnerISO3=="OAS"
replace PartnerISO3="SRB" if PartnerISO3=="SER"
replace PartnerISO3="TLS" if PartnerISO3=="TMP"
replace PartnerISO3="SDN" if PartnerISO3=="SUD"
replace PartnerISO3="MNE" if PartnerISO3=="MNT"
replace ReporterISO3="COD" if ReporterISO3=="ZAR"
replace ReporterISO3="ROU" if ReporterISO3=="ROM"
replace ReporterISO3="TWN" if ReporterISO3=="OAS"
replace ReporterISO3="SRB" if ReporterISO3=="SER"
replace ReporterISO3="TLS" if ReporterISO3=="TMP"
replace ReporterISO3="SDN" if ReporterISO3=="SUD"
replace ReporterISO3="MNE" if ReporterISO3=="MNT"
drop reportername partnername
rename tradev value
tostring HS17, replace
replace HS = "0" + HS if length(HS) == 5
replace HS = "0" + HS if length(HS) == 3

save "$main\master.dta", replace


merge m:m HS using  "$main\mp_hscode.dta" 
order _m
so _m
drop _m

** Check duplicated HS codes so that it can be dropped for calculation of the aggregation **
bysort HS17 pro1 : gen tag = (_n == 1)
bysort HS17 : egen nprod = total(tag)
gen multi_group = (nprod >= 2)
order ReporterISO3 PartnerISO3 year tradeflowname tradeflowcode value pro1 pro2 multi_group HS17
label var multi_g "1 if the HS code appears in 2 or more product groups"
so multi_group HS17

preserve
keep HS17 multi pro1
duplicates drop
keep if multi==1
list

*also EG 441873 and 441875 and 4418 in EUDR is overlapped****
////////This is for the aggregation of all mitigation policies///////////////////
restore


rename Rep re_iso3
rename Par pa_iso3
rename tradeflowname flowname
drop  tag nprod
drop nomen
rename tradeflowcode flowcode
drop productdescription
tempfile raw
save `raw', replace
save "$main\master_raw.dta",replace
clear


*******************Total merchandise exports by country and year*********************
import delimited "$main\TME.csv"

rename productcode HS17
rename reporteriso3 ReporterISO3
rename partneriso3 PartnerISO3
drop reportername partnername HS
rename tradev value

replace PartnerISO3="COD" if PartnerISO3=="ZAR"
replace PartnerISO3="ROU" if PartnerISO3=="ROM"
replace PartnerISO3="TWN" if PartnerISO3=="OAS"
replace PartnerISO3="SRB" if PartnerISO3=="SER"
replace PartnerISO3="TLS" if PartnerISO3=="TMP"
replace PartnerISO3="SDN" if PartnerISO3=="SUD"
replace PartnerISO3="MNE" if PartnerISO3=="MNT"
replace ReporterISO3="COD" if ReporterISO3=="ZAR"
replace ReporterISO3="ROU" if ReporterISO3=="ROM"
replace ReporterISO3="TWN" if ReporterISO3=="OAS"
replace ReporterISO3="SRB" if ReporterISO3=="SER"
replace ReporterISO3="TLS" if ReporterISO3=="TMP"
replace ReporterISO3="SDN" if ReporterISO3=="SUD"
replace ReporterISO3="MNE" if ReporterISO3=="MNT"
so Rep
rename PartnerISO3 pa_iso3
collapse(sum) value,by( nomenclature pa year tradeflowname tradeflowcode)
drop tradeflowcode
rename trade flowname
rename value ttvalue
so pa y
format ttvalue %13.0fc
label var ttvalue "USD1000"
save "$main\tme.dta",replace

clear

******************** GDP by country and year *************************************************

clear
import excel "$main\GDP 2018-2023.xlsx", sheet("WB data") firstrow
drop if missing(y)
drop if missing(GDP)
tempfile wb
save `wb',replace
clear
import excel "$main\GDP 2018-2023.xlsx", sheet("IMF") firstrow
rename Y year
merge 1:1 iso3 year using `wb'
drop _m
duplicates list iso3 y
//drop country
rename iso pa_iso3
so pa year
rename GDP gdp
format gdp %15.0fc
save "$main\gdp 2018-2023.dta",replace

************************************************
clear
use `raw'
merge m:1 pa_iso3 year flowname using "$main\tme.dta"
keep if _m==3
drop _m
merge m:1 pa_iso3 year using "$main\gdp 2018-2023.dta"
keep if _m==3
drop _m
order pa_iso3 re_iso3 year pro1 pro2 value ttvalue gdp


local eu_members "AUT BEL BGR HRV CYP CZE DNK EST FIN FRA DEU GRC HUN IRL ITA LVA LTU LUX MLT NLD POL PRT ROU SVK SVN ESP SWE"
// Step 2: Generate the binary variable 'eu_member' and initialize it to 0///
gen eu_member = 0
// Step 3: Loop over each EU member code and set 'eu_member' to 1 for matches///
foreach code in `eu_members' {
    replace eu_member = 1 if re_iso3 == "`code'"
}
rename eu_member eu_rep

local eu_members "AUT BEL BGR HRV CYP CZE DNK EST FIN FRA DEU GRC HUN IRL ITA LVA LTU LUX MLT NLD POL PRT ROU SVK SVN ESP SWE"
// Step 2: Generate the binary variable 'eu_member' and initialize it to 0///
gen eu_member = 0
// Step 3: Loop over each EU member code and set 'eu_member' to 1 for matches///
foreach code in `eu_members' {
    replace eu_member = 1 if pa_iso3 == "`code'"
}
rename eu_member eu_pa

drop if eu_re==1
save `raw',replace
*************************************************
drop if flowcode==6

gen mkt=4
replace mkt=1 if re_iso3=="CHN"
replace mkt=2 if re_iso3=="EU-UK"
replace mkt=3 if re_iso3=="USA"

collapse(sum) value, by( pa_iso3 mkt year pro1 ttvalue gdp eu_pa)
replace value=value/1000
replace ttv=ttv/1000
replace gdp=gdp/1000
reshape wide value, i(pa year pro1 )j(mkt)
egen cheuus=rowtotal( value1 value2 value3)
egen value5=rowtotal( value1 value2 value3 value4)
gen se=cheuus/value5*100
gen ee=cheuus/gdp*100
gen ee2=cheuus/ttvalue*100
drop if pro1=="EUDR"|pro1=="CBAM"
tempfile mp
save `mp',replace

clear
use `raw'
drop if flowcode==6

keep if pro1=="EUDR"|pro1=="CBAM"
replace eu_rep=1 if re_iso=="EU-UK"
collapse(sum) value, by( pa_iso3 eu_rep year pro1 eu_pa ttvalue gdp )
replace value=value/1000
replace ttv=ttv/1000
replace gdp=gdp/1000
reshape wide value, i(pa year pro1 )j( eu_rep )
rename value1 value2
rename value0 value4
egen value5=rowtotal(value2 value4)
gen se= value2 /value5*100
gen ee= value2 /gdp*100
gen ee2= value2 /ttvalue*100
append using `mp'


lab var pa "iso3"
lab var y "year"
lab var pro1 "group"
lab var value1 "China (USD mill)"
lab var value2 "EU (USD mill)"
lab var value3 "US (USD mill)"
lab var value4 "Rest of world (USD mill)"
lab var value5 "World (USD mill)"
lab var cheuus "China,EU and US (USD mill)"
lab var ttvalue "Toal merchandise exports to world (USD mill)
lab var gdp "GDP (USD mill)"
lab var se "Sector exposure (% of exports to world)"
lab var ee "Economic exposure (% of GDP))"
lab var ee2 "Economic exposure (% of total merchandise exports)"
rename eu_p eu_member
lab var eu_m "1=EU memeber"
order pa_iso3 year pro1 value* cheuus se ee ee2 ttvalue gdp
save `mp',replace

clear
use "$wb_class"
rename iso3 pa_iso3
merge 1:m pa_iso3 using `mp'
order _m
so _m
keep if _m==3
drop _m
so pa y pro
order pa_iso3 country region income year pro1 value1 value2 value3 value4 cheuus ee se ee2
rename cheuus value6
save "$main\master_dup.dta", replace

******** 2. CALCULATION OF EXPORTS OF EACH PRODUCT GROUP IN AGGREGATION: NO OVERLAPPING HS CODES *************

clear
use "$main\mp_hscode.dta"

duplicates list HS

*****720211,720219, 720241,720249,720260: CM and CBAM ; 760421: CM and Renewables; 841290, 841919,841989,841990, 850164, 850231, 850300, 850490  854140 901380 903289 EG and Renewables;854390 EVcomp and EG : total 18 HS codes ***************
drop if pro1=="CM" & inlist(HS, "720211", "720219", "720241", "720249", "720260","760421")
drop if pro1=="EG" & inlist(HS, "841290", "841919","841989", "841990", "850164", "850231", "850300")
drop if pro1=="EG" & inlist(HS, "850490", "854140", "901380", "903289", "854390")


duplicates report HS
merge 1:m HS using "$main\master.dta"
drop _m
rename Rep re_iso3
rename Par pa_iso3
rename tradeflowname flowname
rename tradeflowcode flowcode
local eu_members "AUT BEL BGR HRV CYP CZE DNK EST FIN FRA DEU GRC HUN IRL ITA LVA LTU LUX MLT NLD POL PRT ROU SVK SVN ESP SWE"
gen eu_member = 0
foreach code in `eu_members' {
    replace eu_member = 1 if re_iso3 == "`code'"
}
rename eu_member eu_rep

local eu_members "AUT BEL BGR HRV CYP CZE DNK EST FIN FRA DEU GRC HUN IRL ITA LVA LTU LUX MLT NLD POL PRT ROU SVK SVN ESP SWE"
gen eu_member = 0
foreach code in `eu_members' {
    replace eu_member = 1 if pa_iso3 == "`code'"
}
rename eu_member eu_pa

drop if eu_re==1
drop if flowcode==6 /* Choosing mirror data */
gen mkt=4
replace mkt=1 if re_iso3=="CHN"
replace mkt=2 if re_iso3=="EU-UK"
replace mkt=3 if re_iso3=="USA"
tempfile temp
save `temp',replace

******* 441873 AND 441875 ARE INCLUDED 4418 UNDER EUDR *************
drop if HS=="441873"|HS=="441875"
drop if pro1=="EUDR"|pro1=="CBAM"
collapse(sum) value, by( pa_iso3 mkt year pro1 eu_pa)
replace value=value/1000
reshape wide value, i(pa year pro1 )j(mkt)
egen cheuus=rowtotal( value1 value2 value3)
egen value5=rowtotal( value1 value2 value3 value4)
order pa_iso3 year pro1 value* cheuus
rename cheuus value6
tempfile a
save `a',replace
clear
use `temp'
keep if pro1=="EUDR"|pro1=="CBAM"
drop mkt
replace eu_rep=1 if re_iso=="EU-UK"
collapse(sum) value, by( pa_iso3 eu_rep year pro1 eu_pa)
replace value=value/1000
reshape wide value, i(pa year pro1 )j( eu_rep )
rename value1 value2
rename value0 value4
egen value5=rowtotal(value2 value4)
append using `a'
order pro1 pa year value1 value2 value3 value4 value5 value6
so pro pa year
lab var pa "iso3"
lab var y "year"
lab var pro1 "group"
lab var value1 "China (USD mill)"
lab var value2 "EU (USD mill)"
lab var value3 "US (USD mill)"
lab var value4 "Rest of world (USD mill)"
lab var value5 "World (USD mill)"
lab var value6 "China, EU and US (USD mill)"
lab var eu_p "1=EU member"
format value* %3.2f
save `a',replace

use "$wb_class"
rename iso3 pa_iso3
merge 1:m pa using `a'
order _m
so _m pa
keep if _m==3
drop _m
save "$main\master_nodup.dta",replace
clear

