// FIGURES

replace rank = 0 if rank == .
gen label = cond(level=="Country", country, region)

egen x = group(region rank)
sort x

gen country_m_label = country + " (" + string(round(value2/1000), "%9.0f") + "M)"

//graph bar ec_ex, over (country, sort(x) label(labsize(small) angl(vertical))) blabel(bar, format(%9.2f))

levelsof x, local(xx)
local i = 1
foreach v of local xx {
    label define countrymlbl `v' "`=country_m_label[`i']'", add
    local ++i
}
label values x countrymlbl

twoway ///
    (bar ec_ex x if level=="Country", barwidth(0.8) yaxis(1) color(forest_green)) /// region bars in green
    (bar ec_ex x if level!="Country", barwidth(0.8) yaxis(1) color(navy)) /// country bars in blue
    (scatter se_ex x, yaxis(2) msymbol(O) mcolor(maroon)), ///
    xlabel(1/`=_N', valuelabel labsize(small) angle(vertical)) ///
	   ytitle("Share of GDP (bars)", axis(1) size (small)) ///
	   ytitle("Share of total exports (dots)", axis(2) size (small)) ///
	   xtitle("Country or region average (EUDR exports to the EU, M)", size (small)) ///
	   legend(order(2 "" 1 "EUDR exports to the EU over GDP (LHS)" 3 "EUDR exports to the EU over total exports (RHS)") position(6) size (small) cols(3))

graph export "${path}/Output/Figure1.png", replace